##  Available Actions When Safety Net is Triggered
When the safety net is triggered, the survey creator is informed via email about the affected survey run, the number of new fact sheets, and new recipients added to the survey scope.
![Survey Creator Is Notified When the Safety Net Is Triggered](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746a0e77a441014a366ca52bb4353c3_LowRes.png)
Survey Creator Is Notified When the Safety Net Is Triggered
As a survey creator, you have the following options when the safety net is triggered:
  * Notify all: You approve sending notifications to the new recipients added to the survey.
  * Ignore new Recipients: You exclude the new fact sheets or recipients added to the survey. The survey continues to run with the original scope.
  * Close Survey: Close the survey run altogether.


![Available Actions When Safety Net is Triggered](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753dfe07a4410149f3bbbfe315b7614_LowRes.png)
Available Actions When Safety Net is Triggered
